.. _api:

API
===
.. automodule:: eleanor
    :members:

.. autofunction:: multi_sectors

.. autoclass:: Source
    :members:

.. autoclass:: TargetData
    :members:
    
.. autoclass:: Postcard
    :members:

.. autoclass:: Visualize
    :members:

.. autoclass:: Crossmatch
    :members:

.. autoclass:: ffi
    :members:

.. autofunction:: use_pointing_model
  
.. autofunction:: load_pointing_model

.. autofunction:: pm_quality

.. autofunction:: set_quality_flags
